@@ -30,4 +30,12 @@ def split(string: str, by_substrings: List[str], keep_splitters: bool = True) ->
 def to_english(s: str) -> str:
     import unicodedata
 
-    return ''.join([c for c in unicodedata.normalize('NFD', s) if not unicodedata.combining(c)])
\ No newline at end of file
+    return ''.join([c for c in unicodedata.normalize('NFD', s) if not unicodedata.combining(c)])
+
+def htmlunescape(s: str) -> str:
+    import html
+
+    try:
+        return html.unescape(s)
+    except:
+        return s
\ No newline at end of file
